@@ -25,6 +25,7 @@
 
 #include <glibmm.h>
 #include "document.h"
+#include "keyframes.h"
 
 /*
  *
@@ -36,24 +37,54 @@ public:
 	enum State
 	{
 		NONE,
-		READY,
 		PAUSED,
 		PLAYING
 	};
 
-	/*
-	 *
-	 */
-	Player()
+	enum Message
 	{
-	}
+		STATE_NONE,
+		STATE_PAUSED,
+		STATE_PLAYING,
+		
+		STREAM_READY,
+		STREAM_INFO_CHANGED,
+		STREAM_AUDIO_CHANGED,
+		STREAM_VIDEO_CHANGED,
+		STREAM_DURATION_CHANGED,
+		STREAM_EOS,
+	
+		KEYFRAME_CHANGED,
+	};
 
 	/*
-	 *
 	 */
-	virtual ~Player()
-	{
-	}
+	Player();
+
+	/*
+	 */
+	virtual ~Player();
+
+	/*
+	 */
+	State get_state();
+
+	/*
+	 * Callback used by the player to send message to the application 
+	 * like the change of the state of the player or change on the stream...
+	 */
+	sigc::signal<void, Message>& signal_message();
+
+	/*
+	 * void my_tick(long current_time, long stream_length, double current_position)
+	 *
+	 * current_time: position in the stream in milliseconds
+	 * stream_length: length of the stream in milliseconds
+	 * current_position: position in the stream as a percentage betwwen 0 and 1 (%)
+	 *
+	 * Emitted every time event happens or at regular intervals during playing state.
+	 */
+	sigc::signal<void, long, long, double>& signal_tick();
 
 	/*
 	 * 
@@ -61,7 +92,6 @@ public:
 	virtual bool open(const Glib::ustring &uri) = 0;
 
 	/*
-	 *
 	 */
 	virtual void close() = 0;
 
@@ -71,7 +101,6 @@ public:
 	virtual Glib::ustring get_uri() = 0;
 
 	/*
-	 *
 	 */
 	virtual void play() = 0;
 
@@ -90,50 +119,29 @@ public:
 	virtual void play_segment(const SubtitleTime &start, const SubtitleTime &end) = 0;
 
 	/*
-	 *
 	 */
 	virtual void pause() = 0;
 
 	/*
-	 *
 	 */
 	virtual bool is_playing() = 0;
 
 	/*
-	 *
 	 */
 	virtual long get_duration() = 0;
 
 	/*
-	 *
 	 */
 	virtual long get_position() = 0;
 
 	/*
-	 *
 	 */
 	virtual void seek(long position) = 0;
 
 	/*
-	 *
 	 */
 	virtual void set_subtitle_text(const Glib::ustring &text) = 0;
 
-	/*
-	 *
-	 */
-	virtual State get_state() = 0;
-
-	/*
-	 *
-	 */
-	virtual sigc::signal<void, State>& signal_state_changed() = 0;
-
-	/*
-	 *
-	 */
-	virtual sigc::signal<void>& signal_timeout() = 0;
-
 	/*
 	 * Sets the new playback rate. Used for slow or fast motion.
 	 * Default value : 1.0
@@ -152,6 +160,57 @@ public:
 	 * Works only with play_subtitle.
 	 */
 	virtual void set_repeat(bool state) = 0;
+
+	/*
+	 * Return the number of audio track.
+	 */
+	virtual gint get_n_audio() = 0;
+
+	/*
+	 * Sets the current audio track. (-1 = auto)
+	 */
+	virtual void set_current_audio(gint track) = 0;
+
+	/*
+	 * Return the current audio track.
+	 */
+	virtual gint get_current_audio() = 0;
+
+	/*
+	 */
+	void set_keyframes(Glib::RefPtr<KeyFrames> keyframes);
+
+	/*
+	 */
+	Glib::RefPtr<KeyFrames> get_keyframes();
+
+protected:
+
+	/*
+	 */
+	void set_player_state(State state);
+
+	/*
+	 */
+	void got_tick();
+
+	/*
+	 */
+	bool on_timeout();
+
+	/*
+	 */
+	void send_message(Message msg);
+
+protected:
+	sigc::signal<void, Player::Message> m_signal_message;
+
+	sigc::connection m_timeout_connection;
+	sigc::signal<void, long, long, double> m_signal_tick;
+
+	Player::State m_player_state;
+
+	Glib::RefPtr<KeyFrames> m_keyframes;
 };
 
 #endif//_Player_h
