@@ -293,6 +293,16 @@ void Subtitles::remove(unsigned int start, unsigned int end)
 	remove(subs);
 }
 
+/*
+ * Prefer the function using an array if there is a need to remove several subtitles.
+ */
+void Subtitles::remove(const Subtitle &sub)
+{
+	std::vector<Subtitle> buf;
+	buf.push_back(sub);
+	remove(buf);
+}
+
 /*
  *
  */
@@ -350,7 +360,7 @@ Subtitle Subtitles::get_first_selected()
 /*
  *
  */
-void Subtitles::select(std::vector<Subtitle> &sub)
+void Subtitles::select(const std::vector<Subtitle> &sub)
 {
 	for(unsigned int i=0; i< sub.size(); ++i)
 	{
@@ -358,6 +368,17 @@ void Subtitles::select(std::vector<Subtitle> &sub)
 	}
 }
 
+/*
+ *
+ */
+void Subtitles::select(const std::list<Subtitle> &sub)
+{
+	for(std::list<Subtitle>::const_iterator it = sub.begin(); it != sub.end(); ++it)
+	{
+		m_document.get_subtitle_view()->get_selection()->select((*it).m_iter);
+	}
+}
+
 /*
  *
  */
