@@ -90,6 +90,11 @@ public:
 	 */
 	void remove(unsigned int start, unsigned int end);
 
+	/*
+	 * Prefer the function using an array if there is a need to remove several subtitles.
+	 */
+	void remove(const Subtitle &sub);
+
 	/*
 	 *
 	 */
@@ -117,7 +122,8 @@ public:
 	/*
 	 *
 	 */
-	void select(std::vector<Subtitle> &sub);
+	void select(const std::vector<Subtitle> &sub);
+	void select(const std::list<Subtitle> &sub);
 
 	/*
 	 *
