@@ -24,7 +24,6 @@
 #include "utility.h"
 #include "documentsystem.h"
 #include "subtitleeditorwindow.h"
-#include "waveformgenerator.h"
 
 /*
  *	HACK!
@@ -38,16 +37,16 @@ WaveformRenderer* create_waveform_renderer_gl();
 /*
  *
  */
-WaveformEditor::WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+WaveformEditor::WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :Gtk::HBox(cobject), m_waveformRenderer(NULL), m_document(NULL), m_player(NULL)
 {
 	set_size_request(240, 240);
 
-	refGlade->get_widget("frame-waveform-renderer", m_frameWaveformRenderer);
-	refGlade->get_widget("hscrollbar-waveform-renderer", m_hscrollbarWaveformRenderer);
+	builder->get_widget("frame-waveform-renderer", m_frameWaveformRenderer);
+	builder->get_widget("hscrollbar-waveform-renderer", m_hscrollbarWaveformRenderer);
 
-	refGlade->get_widget("vscale-zoom", m_sliderZoom);
-	refGlade->get_widget("vscale-scale", m_sliderScale);
+	builder->get_widget("vscale-zoom", m_sliderZoom);
+	builder->get_widget("vscale-scale", m_sliderScale);
 
 	// connect signal
 	
@@ -103,9 +102,13 @@ void WaveformEditor::load_config()
 
 	if(cfg.has_key("waveform", "scale"))
 		m_sliderScale->set_value(cfg.get_value_int("waveform", "scale"));
+	else
+		m_sliderScale->set_value(3);
 
 	if(cfg.has_key("waveform", "zoom"))
 		m_sliderZoom->set_value(cfg.get_value_int("waveform", "zoom"));
+	else
+		m_sliderZoom->set_value(1);
 
 	cfg.get_value_bool("waveform", "scrolling-with-player", m_cfg_scrolling_with_player);
 	cfg.get_value_bool("waveform", "scrolling-with-selection", m_cfg_scrolling_with_selection);
@@ -123,6 +126,8 @@ void WaveformEditor::load_config()
  */
 void WaveformEditor::on_create_renderer()
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	Glib::ustring renderer_name = Config::getInstance().get_value_string("waveform", "renderer");
 
 #ifdef ENABLE_GL
@@ -151,6 +156,8 @@ void WaveformEditor::on_create_renderer()
  */
 void WaveformEditor::init_document(Document *doc)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	m_document = NULL;
 	for(unsigned int i=0; i<m_document_connection.size(); ++i)
 		m_document_connection[i].disconnect();
@@ -182,6 +189,8 @@ void WaveformEditor::init_document(Document *doc)
  */
 void WaveformEditor::init_renderer(WaveformRenderer *renderer)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	// Remove the old renderer and destroy.
 	if(m_waveformRenderer != NULL)
 	{
@@ -251,11 +260,16 @@ void WaveformEditor::init_renderer(WaveformRenderer *renderer)
  */
 void WaveformEditor::set_player(Player *player)
 {
+	se_debug(SE_DEBUG_WAVEFORM);
+
 	m_player = player;
 
 	// init
-	m_connection_timeout = m_player->signal_timeout().connect(
-			sigc::mem_fun(*this, &WaveformEditor::on_player_timeout));
+	m_connection_player_tick = m_player->signal_tick().connect(
+			sigc::mem_fun(*this, &WaveformEditor::on_player_tick));
+	// Update the view when the keyframes changed
+	m_player->signal_message().connect(
+			sigc::mem_fun(*this, &WaveformEditor::on_player_message));
 }
 
 /*
@@ -274,39 +288,39 @@ Player* WaveformEditor::player()
 }
 
 /*
- * Enable the signal timeout (Player)
+ * Enable the signal tick (Player)
  */
 void WaveformEditor::on_map()
 {
 	Gtk::HBox::on_map();
 
-	if(m_connection_timeout)
+	if(m_connection_player_tick)
 	{
-		if(m_connection_timeout.connected())
-			m_connection_timeout.unblock();
+		if(m_connection_player_tick.connected())
+			m_connection_player_tick.unblock();
 	}
 
 	redraw_renderer();
 }
 
 /*
- * Disable the signal timeout (Player)
+ * Disable the signal tick (Player)
  */
 void WaveformEditor::on_unmap()
 {
 	Gtk::HBox::on_unmap();
 
-	if(m_connection_timeout)
+	if(m_connection_player_tick)
 	{
-		if(m_connection_timeout.connected())
-			m_connection_timeout.block();
+		if(m_connection_player_tick.connected())
+			m_connection_player_tick.block();
 	}
 }
 
 /*
  *
  */
-void WaveformEditor::on_player_timeout()
+void WaveformEditor::on_player_tick(long current_time, long stream_length, double current_position)
 {
 	if(has_renderer() && player() && has_waveform())
 	{
@@ -333,6 +347,8 @@ long WaveformEditor::get_player_time()
  */
 void WaveformEditor::set_scale(float value)
 {
+	se_debug_message(SE_DEBUG_WAVEFORM, "scale=%f", value);
+
 	m_sliderScale->set_value(value);
 }
 
@@ -349,6 +365,8 @@ float WaveformEditor::get_scale()
  */
 void WaveformEditor::set_zoom(int value)
 {
+	se_debug_message(SE_DEBUG_WAVEFORM, "zoom=%d", value);
+
 	m_sliderZoom->set_value(value);
 }
 
@@ -357,7 +375,10 @@ void WaveformEditor::set_zoom(int value)
  */
 int WaveformEditor::get_zoom()
 {
-	return (int)m_sliderZoom->get_value();
+	int value = (int)m_sliderZoom->get_value();
+	if(value < 1)
+		return 1;
+	return value;
 }
 
 /*
@@ -459,6 +480,9 @@ void WaveformEditor::on_scale_changed()
 
 	se_debug_message(SE_DEBUG_WAVEFORM, "scale=%f", value);
 
+	if(Config::getInstance().get_value_int("waveform", "scale") != value)
+		Config::getInstance().set_value_int("waveform", "scale", value);
+
 	redraw_renderer();
 }
 
@@ -487,7 +511,16 @@ bool WaveformEditor::open_waveform(const Glib::ustring &uri)
  */
 void WaveformEditor::set_waveform(const Glib::RefPtr<Waveform> &wf)
 {
-	se_debug(SE_DEBUG_WAVEFORM);
+	if(wf)
+	{
+		se_debug_message(SE_DEBUG_WAVEFORM, 
+				"uri='%s' video_uri='%s' size='%d' channels='%d' duration='%d'", 
+				wf->get_uri().c_str(), wf->get_video_uri().c_str(), wf->get_size(), wf->get_n_channels(), wf->get_duration());
+	}
+	else
+	{
+		se_debug_message(SE_DEBUG_WAVEFORM, "the waveform RefPtr is NULL");
+	}
 
 	m_waveform = wf;
 
@@ -616,6 +649,21 @@ void WaveformEditor::on_subtitle_time_changed()
 	redraw_renderer();
 }
 
+/*
+ * This callback is connected at the player.
+ * The keyframes has changed, it's need to redraw the view.
+ */
+void WaveformEditor::on_player_message(Player::Message msg)
+{
+	if(msg != Player::KEYFRAME_CHANGED)
+		return;
+	if(!has_renderer())
+		return;
+	
+	renderer()->keyframes_changed();
+	redraw_renderer();
+}
+
 /*
  *
  */
@@ -1038,7 +1086,15 @@ bool WaveformEditor::move_subtitle_end(const SubtitleTime &_time, bool disable_r
 			{
 				SubtitleTime start_of_next_sub = next.get_start();
 
-				if(subtitle_end + min_gap > start_of_next_sub)
+				// Only if the next subtitle is really after this one.
+				// Avoid to invalidate the subtitle end when the next is 
+				// equal to 0:00:000.0 or inferior
+				bool is_really_next = next.get_start() > subtitle.get_start();
+				
+				// Have we an overlapping ?
+				bool is_on_next = subtitle_end + min_gap > start_of_next_sub;
+				
+				if(is_on_next && is_really_next)
 				{
 					// if around is enable
 					// try to move the start of the next subtitle
@@ -1107,17 +1163,3 @@ void WaveformEditor::on_config_waveform_changed(const Glib::ustring &key, const
 	}
 }
 
-/*
- * Try to generate a wavefrom from the media.
- */
-bool WaveformEditor::generate_waveform(const Glib::ustring &media_uri)
-{
-	Glib::RefPtr<Waveform> wf = WaveformGenerator::create(media_uri);
-	if(wf)
-	{
-		set_waveform(wf);
-		return true;
-	}
-	return false;
-}
-
