@@ -25,6 +25,9 @@
 #include "utility.h"
 #include "document.h"
 #include "waveformrenderer.h"
+#include "subtitleeditorwindow.h"
+#include "keyframes.h"
+#include "player.h"
 
 #include <gtkglmm.h>
 #include <GL/gl.h>
@@ -147,6 +150,11 @@ public:
 	 */
 	void display_time_info(const Gdk::Rectangle &area);
 
+	/*
+	 * Draw the keyframes position.
+	 */
+	void draw_keyframes(const Gdk::Rectangle &area);
+
 	/*
 	 * Delete the OpenGL Display List (Waveform)
 	 */
@@ -169,6 +177,12 @@ public:
 	 */
 	void waveform_changed();
 
+	/*
+	 * The keyframe is changed.
+	 * Need to redisplay the waveform.
+	 */
+	void keyframes_changed();
+
 	/*
 	 * Call queue_draw
 	 */
@@ -487,7 +501,10 @@ void WaveformRendererGL::draw(GdkEventExpose *ev)
 		draw_timeline(timeline_area);
 	glPopMatrix();
 
-	
+	// FIXME: test it
+	// keyframes
+	//draw_keyframes(waveform_area);
+
 	// player position
 	{
 		glColor4fv(m_color_player_position);
@@ -699,17 +716,23 @@ void WaveformRendererGL::draw_timeline(const Gdk::Rectangle &area)
 	long sec_5 = SubtitleTime(0,0,5,0).totalmsecs;
 	long sec_10 = SubtitleTime(0,0,10,0).totalmsecs;
 
-	int text_width = get_text_width("0:00:00");
-	
+	if(get_pos_by_time(sec_1) <= 0)
+		return;
 
-	while(get_pos_by_time(sec_1) < text_width + text_width * 0.5)//60)
+	int text_width = get_text_width("0:00:00");
+
+	float margin = text_width + text_width * 0.5;
+	while(get_pos_by_time(sec_1) < margin)
 	{
+		// for a sufficiently long duration sec_* will overflow before
+		// the loop terminates. check the largest of them.
+		if (sec_10 > (LONG_MAX/2))
+			break;
 		sec_1  *= 2;
 		sec_5  *= 2;
 		sec_10 *= 2;
 	}
 
-
 	draw_timeline_msecs(area, sec_1, 3);
 	draw_timeline_msecs(area, sec_5, 6);
 	draw_timeline_msecs(area, sec_10, 10);
@@ -807,6 +830,41 @@ void WaveformRendererGL::display_time_info(const Gdk::Rectangle &area)
 	}
 }
 
+/*
+ */
+void WaveformRendererGL::draw_keyframes(const Gdk::Rectangle &rect)
+{
+	Player *player = SubtitleEditorWindow::get_instance()->get_player();
+	if(player == NULL)
+		return;
+
+	Glib::RefPtr<KeyFrames> keyframes = player->get_keyframes();
+	if(!keyframes)
+		return;
+
+	int height = rect.get_height();
+
+	glColor4fv(m_color_keyframe);
+
+	long start_clip = get_time_by_pos(get_start_area());
+	long end_clip = get_time_by_pos(get_end_area());
+
+	glBegin(GL_LINES);
+	for(KeyFrames::const_iterator it = keyframes->begin(); it != keyframes->end(); ++it)
+	{
+		// display only if it's in the area
+		if(*it < start_clip && *it < end_clip)
+			continue;
+		if(*it > end_clip)
+			break; // the next keyframes are out of the area
+
+		long pos = get_pos_by_time(*it);
+		glVertex2f(pos, 0);
+		glVertex2f(pos, height);
+	}
+	glEnd();
+}
+
 /*
  * Draw the left and the right marker of the subtitle selected. 
  */
@@ -988,6 +1046,13 @@ void WaveformRendererGL::waveform_changed()
 	queue_draw();
 }
 
+/*
+ */
+void WaveformRendererGL::keyframes_changed()
+{
+	queue_draw();
+}
+
 /*
  * Call queue_draw
  */
